@@ -7,7 +7,6 @@ __path__ = extend_path(__path__, __name__)  # type: ignore
 
 from ng_nx.query_reader import NebulaReader
 from ng_nx.scan_reader import NebulaScanReader
-from ng_nx.utils import NebulaGraphConfig
 from ng_nx.writer import NebulaWriter
 
 # export
@@ -15,5 +14,4 @@ __all__ = (
     "NebulaReader",
     "NebulaScanReader",
     "NebulaWriter",
-    "NebulaGraphConfig",
 )
