@@ -9,7 +9,7 @@ from nebula3.Config import Config
 from nebula3.data.ResultSet import ResultSet
 from nebula3.gclient.net import ConnectionPool
 
-from ng_nx import NebulaGraphConfig
+from ng_nx.utils import NebulaGraphConfig
 
 
 class NebulaScanReader:
